package com.emato.cus.supervise.biz.acqGoodsSeat;

import com.emato.cus.supervise.biz.WmsData;
import com.emato.cus.supervise.constant.EmtRecordTimeEnum;
import com.emato.cus.supervise.domain.WmsAcqGoodsOnSeat;
import com.emato.cus.supervise.domainOmsShop.OmsShopAcqGoodsSeat;
import com.emato.cus.supervise.service.omsshop.OmsShopAcqGoodsSeatService;
import com.emato.cus.supervise.service.wms.WmsAcqGoodsOnSeatService;
import com.google.common.collect.ImmutableMap;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Collections;
import java.util.List;

/**
 * 门店库位 即oms门店库存
 * @author Scott Chen
 * @version 1.0
 * 2020-03-30 11:27
 */
@Component
public class AcqGoodsOnSeatOmsShopData {
    private static final Logger logger = LoggerFactory.getLogger(AcqGoodsOnSeatOmsShopData.class);

    @Autowired
    private OmsShopAcqGoodsSeatService omsShopAcqGoodsOnSeatService;

    private static final String DATA_TYPE_INFO = "[" + EmtRecordTimeEnum.OMS_SHOP_ACQ_GOODS_ON_SEAT.getCode() + "]" + EmtRecordTimeEnum.OMS_SHOP_ACQ_GOODS_ON_SEAT.getName();


    public List getOmsShopData(String thisTime) {
        logger.info("---------- 门店在库库存::获取本次监控数据开始 --------------------");

        if (StringUtils.isBlank(thisTime)) {
            String err = "---【" + DATA_TYPE_INFO + "】本次扫描时间为空.";
            logger.error(err);
            return Collections.EMPTY_LIST;
        }

        ImmutableMap param = ImmutableMap.of("thisTime", thisTime);
        List<OmsShopAcqGoodsSeat> resultList = omsShopAcqGoodsOnSeatService.getOmsShopAcqGoodsSeat(param);

        if (resultList == null || resultList.size() == 0) {
            String err = "---【" + DATA_TYPE_INFO + "】获取本次监控数据为空.";
            logger.error(err);
            return Collections.EMPTY_LIST;
        }
        logger.info("---【" + DATA_TYPE_INFO + "】获取本次监控数据{}条.", resultList.size());

        logger.info("---------- 门店在库库存::获取本次监控数据结束 --------------------");

        return resultList;
    }
}
